@@ -48,9 +48,9 @@ def add_alarm_status(
         print(new_alarm_status)
     """
     alarm_status_input = AddAlarmStatusInput(name=name)
-    if (name is None):
+    if (name is ""):
       print ("you cant leave the name parameter empt")
-    elif (name!=str):
+    elif name!=str:
       print ("the input must be a text, example name=''new name''")
     else:
         result = addAlarmStatus.execute(client, input=alarm_status_input)
